@@ -203,9 +203,9 @@ class Base(Controller):
         tmux_path = os.path.join('/'.join(tmux))
         if self.app.pargs.shell == 'sh':
             os.system(f'cat {zshrc_path} >> ~/.bashrc ')
-        if self.app.pargs.shell == 'zsh':
+        elif self.app.pargs.shell == 'zsh':
             os.system(f'cat {zshrc_path} >> ~/.zshrc ')
-        if self.app.pargs.shell == 'tmux':
+        elif self.app.pargs.shell == 'tmux':
             os.system(f'cat {tmux_path} >> ~/.tmux.conf ')
         else:
             raise NotImplementedError("Try one of {sh, zsh, tmux}")
@@ -347,7 +347,6 @@ class Base(Controller):
     )
     def config(self):
         # TODO: setup Data-toolkit specific config
-        from ..ext.config_cmd import config
         args = self.app.pargs
 
         # shows config
