@@ -23,9 +23,11 @@ def check_if_aux(ip_permissions: list):
     except IndexError as e:
         assert ip_permissions['IpRanges']==[]
         return False
+    except KeyError as e:
+        return False
 
 def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
-                    ports=[22, 8501, 8888], profile='default'):
+                    ports=[22, 8888, 8501, 8889, 5432], profile='default'):
     import boto3
 
     ip = f"{get_public_ip()}/32"
@@ -43,27 +45,23 @@ def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
     permissions_to_revoke = [ s for s in sg_res.ip_permissions if check_if_aux(s) ]
 
     # Removes all relevant permissions from this group (originally as `jakub`)
-    if sg_res.ip_permissions!=[]:
+    if sg_res.ip_permissions!=[] and permissions_to_revoke!=[]:
+        print('No permissions to revoke. Skipping.')
         sg_res.revoke_ingress(IpPermissions=permissions_to_revoke)
 
+    # TODO: align with ports
+    descriptions = [ 'Jakub Aux SSH','Jakub Aux Jupyter', 'Jakub Aux Streamlit', 'Jakub Aux Jupyter2', 'Jakub Aux Postgres']
+
+    ip_perms = [ {
+        'IpProtocol': 'tcp',
+        'FromPort': ports[i],
+        'ToPort': ports[i],
+        'IpRanges': [{'CidrIp': ip, 'Description': descriptions[i]}]
+    } for i in range(len(descriptions)) ]
+
+    # print(ip_perms)
 
-    description = 'Jakub Aux Jupyter'
-    description2 = 'Jakub Aux SSH'
-    description3 = 'Jakub Aux Streamlit'
     data = ec2.authorize_security_group_ingress(
             GroupId=target_sg_str['GroupId'],
-            IpPermissions=[
-                {'IpProtocol': 'tcp',
-                'FromPort': 8888,
-                'ToPort': 8888,
-                'IpRanges': [{'CidrIp': ip, 'Description': description}] },
-                {'IpProtocol': 'tcp',
-                'FromPort': 22,
-                'ToPort': 22,
-                'IpRanges': [{'CidrIp': ip, 'Description': description2}]},
-                {'IpProtocol': 'tcp',
-                'FromPort': 8501,
-                'ToPort': 8501,
-                'IpRanges': [{'CidrIp': ip, 'Description': description2}]}
-            ])
+            IpPermissions=ip_perms )
     print('Ingress Successfully Set %s' % data)
